﻿
#region Using Directives

using System;
using System.Windows;
using TuneDepot.Models;
using TuneDepot.ViewModels;

#endregion

namespace TuneDepot
{

    /// <summary>
    /// Represents the TuneDepot silverlight application.
    /// </summary>
    public partial class App : Application
    {

        #region Constructor

        /// <summary>
        /// The constructor of the application. Loads and shows the main page.
        /// </summary>
        public App()
        {

            this.Startup += this.Application_Startup;
            this.UnhandledException += this.Application_UnhandledException;

            InitializeComponent();
        
        }

        #endregion

        #region Event Handling

        /// <summary>
        /// Is called, when the application is started.
        /// </summary>
        /// <param name="sender">
        /// The sender, in this case the application.
        /// </param>
        /// <param name="e">
        /// The event arguments.
        /// </param>
        private void Application_Startup(object sender, StartupEventArgs e)
        {

            // Wait for the download of the album data to be completed
            MusicAlbumsModel.DownloadCompleted += new MusicAlbumsModel.DownloadCompletedEventHandler(MusicAlbumsModel_DownloadCompleted);
        
        }

        /// <summary>
        /// Is called, when the album data was downloaded. Opens the main page and sets its
        /// data context to its view model.
        /// </summary>
        void MusicAlbumsModel_DownloadCompleted()
        {

            MainPageViewModel viewModel = new MainPageViewModel();
            MainPage mainPage = new MainPage();
            mainPage.LayoutRoot.DataContext = viewModel;
            this.RootVisual = mainPage;

        }

        /// <summary>
        /// Is called for each unhandled exception. Reports them to the browser,
        /// where they are handled by a JavaScript function.
        /// </summary>
        /// <param name="sender">
        /// The sender.
        /// </param>
        /// <param name="e">
        /// The event arguments.
        /// </param>
        private void Application_UnhandledException(object sender, ApplicationUnhandledExceptionEventArgs e)
        {

            if (!System.Diagnostics.Debugger.IsAttached)
            {

                e.Handled = true;
                Deployment.Current.Dispatcher.BeginInvoke(delegate { ReportErrorToDOM(e); });
            
            }
        
        }

        #endregion

        #region Methods

        /// <summary>
        /// Reports the unhandled error to the browser where it is handled by a silverlight function.
        /// </summary>
        /// <param name="e"></param>
        private void ReportErrorToDOM(ApplicationUnhandledExceptionEventArgs e)
        {
        
            try
            {
            
                string errorMsg = e.ExceptionObject.Message + e.ExceptionObject.StackTrace;
                errorMsg = errorMsg.Replace('"', '\'').Replace("\r\n", @"\n");

                System.Windows.Browser.HtmlPage.Window.Eval("throw new Error(\"Unhandled Error in Silverlight Application " + errorMsg + "\");");
            
            }
            catch (Exception)
            {
            }

        }

        #endregion

    }

}
