﻿
#region Using Directives

using System;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows;

#endregion

namespace TuneDepot.Controls
{

    /// <summary>
    /// Represents a user control, which is a window.
    /// </summary>
    public partial class ContentWindow : UserControl
    {

        #region Constructor

        /// <summary>
        /// The constructor of the content window, which initializes its components.
        /// </summary>
        public ContentWindow()
        {

            InitializeComponent();

        }

        #endregion

        #region Public Properties

        /// <summary>
        /// Gets or sets the brush, which fills the background of the content window.
        /// </summary>
        public new Brush Background
        {

            get
            {

                return WindowBackground.Fill;

            }

            set
            {

                WindowBackground.Fill = value;

            }

        }

        /// <summary>
        /// Gets or sets the title of the content window.
        /// </summary>
        public string Title
        {

            get
            {

                return WindowTitle.Text;

            }

            set
            {

                WindowTitle.Text = value;

            }
        
        }

        /// <summary>
        /// Gets or sets the opacity of the content window.
        /// </summary>
        public new double Opacity
        {

            get
            {

                return WindowBackground.Opacity;

            }

            set
            {

                WindowBackground.Opacity = value;
                WindowContent.Opacity = value + 0.2;

            }
        
        }

        /// <summary>
        /// Gets or sets the children of the window.
        /// </summary>
        public new UIElement Content
        {

            get
            {

                return WindowContent.Children[0];

            }

            set
            {

                WindowContent.Children.Clear();
                WindowContent.Children.Add(value);

            }
        
        }

        #endregion

    }

}
